import colorama
print(colorama.Fore.BLUE+'Pygl version - (17.4)'+colorama.Fore.RESET)
print(colorama.Fore.CYAN+colorama.Style.BRIGHT+'My Github --- ( https://github.com/dedisvoin/GRPgraph-versions )'+colorama.Fore.RESET,colorama.Style.RESET_ALL)
__version__ = '17.3'